(function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
        var v = factory(require, exports);
        if (v !== undefined) module.exports = v;
    }
    else if (typeof define === "function" && define.amd) {
        define(["require", "exports"], factory);
    }
})(function (require, exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const set = (x = []) => x instanceof Set ? x : new Set(x);
    exports.set = set;
    const and = (a, b) => {
        const A = set(a);
        const B = set(b);
        return set([...A].filter(x => B.has(x)));
    };
    exports.and = and;
    exports.intersect = and;
    const or = (a, b) => set([...a, ...b]);
    exports.or = or;
    exports.union = or;
    const not = (a, b) => {
        const A = set(a);
        const B = set(b);
        return set([...A].filter(x => !B.has(x)));
    };
    exports.not = not;
    exports.subtract = not;
    exports.difference = not;
    const xor = (a, b) => not(or(a, b), and(a, b));
    exports.xor = xor;
    const equal = (a, b) => {
        const A = set(a);
        const B = set(b);
        return A.size === B.size && [...A].every(x => B.has(x));
    };
    exports.equal = equal;
    const subset = (a, b) => {
        const A = set(a);
        const B = set(b);
        return [...A].every(x => B.has(x));
    };
    exports.subset = subset;
    const strictSubset = (a, b) => {
        const A = set(a);
        const B = set(b);
        return A.size < B.size && [...A].every(x => B.has(x));
    };
    exports.strictSubset = strictSubset;
    const superset = (a, b) => subset(b, a);
    exports.superset = superset;
    const strictSuperset = (a, b) => strictSubset(b, a);
    exports.strictSuperset = strictSuperset;
    const intersects = (a, b) => and(a, b).size > 0;
    exports.intersects = intersects;
    const excludes = (a, b) => and(a, b).size === 0;
    exports.excludes = excludes;
});
